//
//  ContentManager.m
//  ContentManager
//
//  Created by Niels Hansen on 10/9/11.
//  Copyright 2013 Agilite Software. All rights reserved.
//

#import "ContentManager.h"
#import "SynthesizeSingleton.h"

@implementation ContentManager

@synthesize prevViewController;
@synthesize managedObjectContext = __managedObjectContext;
@synthesize managedObjectModel = __managedObjectModel;
@synthesize persistentStoreCoordinator = __persistentStoreCoordinator;
@synthesize debugMode;
@synthesize scaleOnDistance;

SYNTHESIZE_SINGLETON_FOR_CLASS(ContentManager);

- (void)dealloc
{
}


-(void) setPrev: (UIViewController*) controller {
	
	if (controllerList == nil)
		controllerList = [[NSMutableArray alloc] init];
	
	[controllerList addObject:controller];
    
    if (prevViewController != nil)
        prevViewController = nil;
	
	[self setPrevViewController: controller];
	
}

-(void) popPrev {
	
    if (controllerList != nil)	{
		if ([controllerList count] > 0)	
			[controllerList removeLastObject];
        
		if ([controllerList count] > 0)
        {
			if (prevViewController != nil)
                prevViewController = nil;

            [self setPrevViewController: (UIViewController*)[controllerList lastObject]];
        }
		else 
			[self setPrevViewController:nil];
	}
	else
		[self setPrevViewController:nil];
}

-(void) goBackFromView:(UIViewController*) currentViewController goBack:(int)popOff {
	
	if (popOff > 1) {
		for (int i=1; i < popOff; i++) {
			[self popPrev];
		}
	}
    
	[UIView beginAnimations:nil context:NULL];
	[UIView setAnimationDuration:0.75];
	[UIView setAnimationTransition:UIViewAnimationTransitionFlipFromLeft forView:[[currentViewController view] superview] cache:YES];
	
	[[currentViewController view] removeFromSuperview];
	[[self prevViewController] viewWillAppear:YES];
	[currentViewController viewWillDisappear:YES];

	
	[[[UIApplication sharedApplication] keyWindow] addSubview:[[self prevViewController] view]];
    //	[currentViewController viewDidDisappear:YES];
    //	[[self prevViewController] viewDidAppear:YES];
	
	[UIView commitAnimations];
	
	[self popPrev];
}

-(void) goToView:(UIViewController*) toViewController fromView:(UIViewController*) fromViewController {
	
    [self setPrev:fromViewController];
    
	[UIView beginAnimations:nil context:NULL];
	[UIView setAnimationDuration:0.75];
	[UIView setAnimationTransition:UIViewAnimationTransitionFlipFromRight forView:[[fromViewController view] superview] cache:YES];
	
	[[fromViewController view] removeFromSuperview];
	[toViewController viewWillAppear:YES];
	[fromViewController viewWillDisappear:YES];
	
	[[[UIApplication sharedApplication] keyWindow] addSubview:[toViewController view]];
    //	[fromViewController viewDidDisappear:YES];
    //	[toViewController viewDidAppear:YES];
	
	[UIView commitAnimations];
    
}

- (void)saveContext
{
    NSError *error = nil;
    NSManagedObjectContext *managedObjectContext = self.managedObjectContext;
    if (managedObjectContext != nil)
    {
        if ([managedObjectContext hasChanges] && ![managedObjectContext save:&error])
        {
            /*
             Replace this implementation with code to handle the error appropriately.
             
             abort() causes the application to generate a crash log and terminate. You should not use this function in a shipping application, although it may be useful during development. If it is not possible to recover from the error, display an alert panel that instructs the user to quit the application by pressing the Home button.
             */
            NSLog(@"Unresolved error %@, %@", error, [error userInfo]);
            abort();
        } 
    }
}

#pragma mark - Core Data stack

/**
 Returns the managed object context for the application.
 If the context doesn't already exist, it is created and bound to the persistent store coordinator for the application.
 */
- (NSManagedObjectContext *)managedObjectContext
{
    if (__managedObjectContext != nil)
    {
        return __managedObjectContext;
    }
    
    NSPersistentStoreCoordinator *coordinator = [self persistentStoreCoordinator];
    if (coordinator != nil)
    {
        __managedObjectContext = [[NSManagedObjectContext alloc] init];
        [__managedObjectContext setPersistentStoreCoordinator:coordinator];
    }
    return __managedObjectContext;
}

/**
 Returns the managed object model for the application.
 If the model doesn't already exist, it is created from the application's model.
 */
- (NSManagedObjectModel *)managedObjectModel
{
    if (__managedObjectModel != nil)
    {
        return __managedObjectModel;
    }
    NSURL *modelURL = [[NSBundle mainBundle] URLForResource:@"ARKitDemo" withExtension:@"momd"];
    __managedObjectModel = [[NSManagedObjectModel alloc] initWithContentsOfURL:modelURL];    
    return __managedObjectModel;
}

/**
 Returns the persistent store coordinator for the application.
 If the coordinator doesn't already exist, it is created and the application's store added to it.
 */
- (NSPersistentStoreCoordinator *)persistentStoreCoordinator
{
    if (__persistentStoreCoordinator != nil)
    {
        return __persistentStoreCoordinator;
    }
    
    NSString *sqlName = [NSString stringWithFormat:@"%@.sqlite", [[[NSBundle mainBundle] infoDictionary]   objectForKey:@"CFBundleName"]];
    
    NSLog(@"%@",sqlName);
    
    NSURL *storeURL = [[self applicationDocumentsDirectory] URLByAppendingPathComponent:sqlName];
    
    NSError *error = nil;
    __persistentStoreCoordinator = [[NSPersistentStoreCoordinator alloc] initWithManagedObjectModel:[self managedObjectModel]];
    if (![__persistentStoreCoordinator addPersistentStoreWithType:NSSQLiteStoreType configuration:nil URL:storeURL options:nil error:&error])
    {
        /*
         Replace this implementation with code to handle the error appropriately.
         
         abort() causes the application to generate a crash log and terminate. You should not use this function in a shipping application, although it may be useful during development. If it is not possible to recover from the error, display an alert panel that instructs the user to quit the application by pressing the Home button.
         
         Typical reasons for an error here include:
         * The persistent store is not accessible;
         * The schema for the persistent store is incompatible with current managed object model.
         Check the error message to determine what the actual problem was.
         
         
         If the persistent store is not accessible, there is typically something wrong with the file path. Often, a file URL is pointing into the application's resources directory instead of a writeable directory.
         
         If you encounter schema incompatibility errors during development, you can reduce their frequency by:
         * Simply deleting the existing store:
         [[NSFileManager defaultManager] removeItemAtURL:storeURL error:nil]
         
         * Performing automatic lightweight migration by passing the following dictionary as the options parameter: 
         [NSDictionary dictionaryWithObjectsAndKeys:[NSNumber numberWithBool:YES], NSMigratePersistentStoresAutomaticallyOption, [NSNumber numberWithBool:YES], NSInferMappingModelAutomaticallyOption, nil];
         
         Lightweight migration will only work for a limited set of schema changes; consult "Core Data Model Versioning and Data Migration Programming Guide" for details.
         
         */
        NSLog(@"Unresolved error %@, %@", error, [error userInfo]);
        abort();
    }    
    
    return __persistentStoreCoordinator;
}

#pragma mark - Application's Documents directory

/**
 Returns the URL to the application's Documents directory.
 */
- (NSURL *)applicationDocumentsDirectory
{
    return [[[NSFileManager defaultManager] URLsForDirectory:NSDocumentDirectory inDomains:NSUserDomainMask] lastObject];
}



@end
